<?php

return [
    'Names' => [
        'af' => 'အာဖရိကန်',
        'af_NA' => 'အာဖရိကန် (နမီးဘီးယား)',
        'af_ZA' => 'အာဖရိကန် (တောင်အာဖရိက)',
        'ak' => 'အာကန်',
        'ak_GH' => 'အာကန် (ဂါနာ)',
        'am' => 'အမ်ဟာရစ်ခ်',
        'am_ET' => 'အမ်ဟာရစ်ခ် (အီသီယိုးပီးယား)',
        'ar' => 'အာရဗီ',
        'ar_001' => 'အာရဗီ (ကမ္ဘာ)',
        'ar_AE' => 'အာရဗီ (ယူအေအီး)',
        'ar_BH' => 'အာရဗီ (ဘာရိန်း)',
        'ar_DJ' => 'အာရဗီ (ဂျီဘူတီ)',
        'ar_DZ' => 'အာရဗီ (အယ်လ်ဂျီးရီးယား)',
        'ar_EG' => 'အာရဗီ (အီဂျစ်)',
        'ar_EH' => 'အာရဗီ (အနောက် ဆာဟာရ)',
        'ar_ER' => 'အာရဗီ (အီရီထရီးယား)',
        'ar_IL' => 'အာရဗီ (အစ္စရေး)',
        'ar_IQ' => 'အာရဗီ (အီရတ်)',
        'ar_JO' => 'အာရဗီ (ဂျော်ဒန်)',
        'ar_KM' => 'အာရဗီ (ကိုမိုရိုစ်)',
        'ar_KW' => 'အာရဗီ (ကူဝိတ်)',
        'ar_LB' => 'အာရဗီ (လက်ဘနွန်)',
        'ar_LY' => 'အာရဗီ (လစ်ဗျား)',
        'ar_MA' => 'အာရဗီ (မော်ရိုကို)',
        'ar_MR' => 'အာရဗီ (မော်ရီတေးနီးယား)',
        'ar_OM' => 'အာရဗီ (အိုမန်)',
        'ar_PS' => 'အာရဗီ (ပါလက်စတိုင်း ပိုင်နက်)',
        'ar_QA' => 'အာရဗီ (ကာတာ)',
        'ar_SA' => 'အာရဗီ (ဆော်ဒီအာရေးဘီးယား)',
        'ar_SD' => 'အာရဗီ (ဆူဒန်)',
        'ar_SO' => 'အာရဗီ (ဆိုမာလီယာ)',
        'ar_SS' => 'အာရဗီ (တောင် ဆူဒန်)',
        'ar_SY' => 'အာရဗီ (ဆီးရီးယား)',
        'ar_TD' => 'အာရဗီ (ချဒ်)',
        'ar_TN' => 'အာရဗီ (တူနီးရှား)',
        'ar_YE' => 'အာရဗီ (ယီမင်)',
        'as' => 'အာသံ',
        'as_IN' => 'အာသံ (အိန္ဒိယ)',
        'az' => 'အဇာဘိုင်ဂျန်',
        'az_AZ' => 'အဇာဘိုင်ဂျန် (အဇာဘိုင်ဂျန်)',
        'az_Cyrl' => 'အဇာဘိုင်ဂျန် (စစ်ရိလစ်)',
        'az_Cyrl_AZ' => 'အဇာဘိုင်ဂျန် (စစ်ရိလစ်/ အဇာဘိုင်ဂျန်)',
        'az_Latn' => 'အဇာဘိုင်ဂျန် (လက်တင်)',
        'az_Latn_AZ' => 'အဇာဘိုင်ဂျန် (လက်တင်/ အဇာဘိုင်ဂျန်)',
        'be' => 'ဘီလာရုစ်',
        'be_BY' => 'ဘီလာရုစ် (ဘီလာရုစ်)',
        'bg' => 'ဘူလ်ဂေးရီးယား',
        'bg_BG' => 'ဘူလ်ဂေးရီးယား (ဘူလ်ဂေးရီးယား)',
        'bm' => 'ဘန်ဘာရာ',
        'bm_ML' => 'ဘန်ဘာရာ (မာလီ)',
        'bn' => 'ဘင်္ဂါလီ',
        'bn_BD' => 'ဘင်္ဂါလီ (ဘင်္ဂလားဒေ့ရှ်)',
        'bn_IN' => 'ဘင်္ဂါလီ (အိန္ဒိယ)',
        'bo' => 'တိဘက်',
        'bo_CN' => 'တိဘက် (တရုတ်)',
        'bo_IN' => 'တိဘက် (အိန္ဒိယ)',
        'br' => 'ဘရီတွန်',
        'br_FR' => 'ဘရီတွန် (ပြင်သစ်)',
        'bs' => 'ဘော့စ်နီးယား',
        'bs_BA' => 'ဘော့စ်နီးယား (ဘော့စနီးယားနှင့် ဟာဇီဂိုဗီနား)',
        'bs_Cyrl' => 'ဘော့စ်နီးယား (စစ်ရိလစ်)',
        'bs_Cyrl_BA' => 'ဘော့စ်နီးယား (စစ်ရိလစ်/ ဘော့စနီးယားနှင့် ဟာဇီဂိုဗီနား)',
        'bs_Latn' => 'ဘော့စ်နီးယား (လက်တင်)',
        'bs_Latn_BA' => 'ဘော့စ်နီးယား (လက်တင်/ ဘော့စနီးယားနှင့် ဟာဇီဂိုဗီနား)',
        'ca' => 'ကတ်တလန်',
        'ca_AD' => 'ကတ်တလန် (အန်ဒိုရာ)',
        'ca_ES' => 'ကတ်တလန် (စပိန်)',
        'ca_FR' => 'ကတ်တလန် (ပြင်သစ်)',
        'ca_IT' => 'ကတ်တလန် (အီတလီ)',
        'ce' => 'ချက်ချန်း',
        'ce_RU' => 'ချက်ချန်း (ရုရှား)',
        'cs' => 'ချက်',
        'cs_CZ' => 'ချက် (ချက်ကီယား)',
        'cv' => 'ချူဗက်ရှ်',
        'cv_RU' => 'ချူဗက်ရှ် (ရုရှား)',
        'cy' => 'ဝေလ',
        'cy_GB' => 'ဝေလ (ယူနိုက်တက်ကင်းဒမ်း)',
        'da' => 'ဒိန်းမတ်',
        'da_DK' => 'ဒိန်းမတ် (ဒိန်းမတ်)',
        'da_GL' => 'ဒိန်းမတ် (ဂရင်းလန်း)',
        'de' => 'ဂျာမန်',
        'de_AT' => 'ဂျာမန် (ဩစတြီးယား)',
        'de_BE' => 'ဂျာမန် (ဘယ်လ်ဂျီယမ်)',
        'de_CH' => 'ဂျာမန် (ဆွစ်ဇာလန်)',
        'de_DE' => 'ဂျာမန် (ဂျာမနီ)',
        'de_IT' => 'ဂျာမန် (အီတလီ)',
        'de_LI' => 'ဂျာမန် (လစ်တန်စတိန်း)',
        'de_LU' => 'ဂျာမန် (လူဇင်ဘတ်)',
        'dz' => 'ဒဇွန်ကာ',
        'dz_BT' => 'ဒဇွန်ကာ (ဘူတန်)',
        'ee' => 'အီဝီ',
        'ee_GH' => 'အီဝီ (ဂါနာ)',
        'ee_TG' => 'အီဝီ (တိုဂို)',
        'el' => 'ဂရိ',
        'el_CY' => 'ဂရိ (ဆိုက်ပရပ်စ်)',
        'el_GR' => 'ဂရိ (ဂရိ)',
        'en' => 'အင်္ဂလိပ်',
        'en_001' => 'အင်္ဂလိပ် (ကမ္ဘာ)',
        'en_150' => 'အင်္ဂလိပ် (ဥရောပ)',
        'en_AE' => 'အင်္ဂလိပ် (ယူအေအီး)',
        'en_AG' => 'အင်္ဂလိပ် (အန်တီဂွါနှင့် ဘာဘူဒါ)',
        'en_AI' => 'အင်္ဂလိပ် (အန်ဂီလာ)',
        'en_AS' => 'အင်္ဂလိပ် (အမေရိကန် ဆမိုးအား)',
        'en_AT' => 'အင်္ဂလိပ် (ဩစတြီးယား)',
        'en_AU' => 'အင်္ဂလိပ် (ဩစတြေးလျ)',
        'en_BB' => 'အင်္ဂလိပ် (ဘာဘေးဒိုးစ်)',
        'en_BE' => 'အင်္ဂလိပ် (ဘယ်လ်ဂျီယမ်)',
        'en_BI' => 'အင်္ဂလိပ် (ဘူရွန်ဒီ)',
        'en_BM' => 'အင်္ဂလိပ် (ဘာမြူဒါ)',
        'en_BS' => 'အင်္ဂလိပ် (ဘဟားမား)',
        'en_BW' => 'အင်္ဂလိပ် (ဘော့ဆွာနာ)',
        'en_BZ' => 'အင်္ဂလိပ် (ဘလိဇ်)',
        'en_CA' => 'အင်္ဂလိပ် (ကနေဒါ)',
        'en_CC' => 'အင်္ဂလိပ် (ကိုကိုးကျွန်း)',
        'en_CH' => 'အင်္ဂလိပ် (ဆွစ်ဇာလန်)',
        'en_CK' => 'အင်္ဂလိပ် (ကွတ် ကျွန်းစု)',
        'en_CM' => 'အင်္ဂလိပ် (ကင်မရွန်း)',
        'en_CX' => 'အင်္ဂလိပ် (ခရစ်စမတ် ကျွန်း)',
        'en_CY' => 'အင်္ဂလိပ် (ဆိုက်ပရပ်စ်)',
        'en_DE' => 'အင်္ဂလိပ် (ဂျာမနီ)',
        'en_DK' => 'အင်္ဂလိပ် (ဒိန်းမတ်)',
        'en_DM' => 'အင်္ဂလိပ် (ဒိုမီနီကာ)',
        'en_ER' => 'အင်္ဂလိပ် (အီရီထရီးယား)',
        'en_FI' => 'အင်္ဂလိပ် (ဖင်လန်)',
        'en_FJ' => 'အင်္ဂလိပ် (ဖီဂျီ)',
        'en_FK' => 'အင်္ဂလိပ် (ဖော့ကလန် ကျွန်းစု)',
        'en_FM' => 'အင်္ဂလိပ် (မိုင်ခရိုနီရှား)',
        'en_GB' => 'အင်္ဂလိပ် (ယူနိုက်တက်ကင်းဒမ်း)',
        'en_GD' => 'အင်္ဂလိပ် (ဂရီနေဒါ)',
        'en_GG' => 'အင်္ဂလိပ် (ဂွန်းဇီ)',
        'en_GH' => 'အင်္ဂလိပ် (ဂါနာ)',
        'en_GI' => 'အင်္ဂလိပ် (ဂျီဘရော်လ်တာ)',
        'en_GM' => 'အင်္ဂလိပ် (ဂမ်ဘီရာ)',
        'en_GU' => 'အင်္ဂလိပ် (ဂူအမ်)',
        'en_GY' => 'အင်္ဂလိပ် (ဂိုင်ယာနာ)',
        'en_HK' => 'အင်္ဂလိပ် (ဟောင်ကောင် [တရုတ်ပြည်])',
        'en_IE' => 'အင်္ဂလိပ် (အိုင်ယာလန်)',
        'en_IL' => 'အင်္ဂလိပ် (အစ္စရေး)',
        'en_IM' => 'အင်္ဂလိပ် (မန်ကျွန်း)',
        'en_IN' => 'အင်္ဂလိပ် (အိန္ဒိယ)',
        'en_IO' => 'အင်္ဂလိပ် (ဗြိတိသျှပိုင် အိန္ဒိယသမုဒ္ဒရာကျွန်းများ)',
        'en_JE' => 'အင်္ဂလိပ် (ဂျာစီ)',
        'en_JM' => 'အင်္ဂလိပ် (ဂျမေကာ)',
        'en_KE' => 'အင်္ဂလိပ် (ကင်ညာ)',
        'en_KI' => 'အင်္ဂလိပ် (ခီရီဘာတီ)',
        'en_KN' => 'အင်္ဂလိပ် (စိန့်ကစ်နှင့်နီဗီစ်)',
        'en_KY' => 'အင်္ဂလိပ် (ကေမန် ကျွန်းစု)',
        'en_LC' => 'အင်္ဂလိပ် (စိန့်လူစီယာ)',
        'en_LR' => 'အင်္ဂလိပ် (လိုက်ဘေးရီးယား)',
        'en_LS' => 'အင်္ဂလိပ် (လီဆိုသို)',
        'en_MG' => 'အင်္ဂလိပ် (မဒါဂတ်စကား)',
        'en_MH' => 'အင်္ဂလိပ် (မာရှယ် ကျွန်းစု)',
        'en_MO' => 'အင်္ဂလိပ် (မကာအို [တရုတ်ပြည်])',
        'en_MP' => 'အင်္ဂလိပ် (မြောက်ပိုင်းမာရီအာနာကျွန်းစု)',
        'en_MS' => 'အင်္ဂလိပ် (မောင့်စဲရက်)',
        'en_MT' => 'အင်္ဂလိပ် (မောလ်တာ)',
        'en_MU' => 'အင်္ဂလိပ် (မောရစ်ရှ)',
        'en_MV' => 'အင်္ဂလိပ် (မော်လ်ဒိုက်)',
        'en_MW' => 'အင်္ဂလိပ် (မာလာဝီ)',
        'en_MY' => 'အင်္ဂလိပ် (မလေးရှား)',
        'en_NA' => 'အင်္ဂလိပ် (နမီးဘီးယား)',
        'en_NF' => 'အင်္ဂလိပ် (နောဖုတ်ကျွန်း)',
        'en_NG' => 'အင်္ဂလိပ် (နိုင်ဂျီးရီးယား)',
        'en_NL' => 'အင်္ဂလိပ် (နယ်သာလန်)',
        'en_NR' => 'အင်္ဂလိပ် (နော်ရူး)',
        'en_NU' => 'အင်္ဂလိပ် (နီဥူအေ)',
        'en_NZ' => 'အင်္ဂလိပ် (နယူးဇီလန်)',
        'en_PG' => 'အင်္ဂလိပ် (ပါပူအာ နယူးဂီနီ)',
        'en_PH' => 'အင်္ဂလိပ် (ဖိလစ်ပိုင်)',
        'en_PK' => 'အင်္ဂလိပ် (ပါကစ္စတန်)',
        'en_PN' => 'အင်္ဂလိပ် (ပစ်တ်ကိန်းကျွန်းစု)',
        'en_PR' => 'အင်္ဂလိပ် (ပေါ်တိုရီကို)',
        'en_PW' => 'အင်္ဂလိပ် (ပလာအို)',
        'en_RW' => 'အင်္ဂလိပ် (ရဝန်ဒါ)',
        'en_SB' => 'အင်္ဂလိပ် (ဆော်လမွန်ကျွန်းစု)',
        'en_SC' => 'အင်္ဂလိပ် (ဆေးရှဲ)',
        'en_SD' => 'အင်္ဂလိပ် (ဆူဒန်)',
        'en_SE' => 'အင်္ဂလိပ် (ဆွီဒင်)',
        'en_SG' => 'အင်္ဂလိပ် (စင်္ကာပူ)',
        'en_SH' => 'အင်္ဂလိပ် (စိန့်ဟယ်လယ်နာ)',
        'en_SI' => 'အင်္ဂလိပ် (ဆလိုဗေးနီးယား)',
        'en_SL' => 'အင်္ဂလိပ် (ဆီယာရာ လီယွန်း)',
        'en_SS' => 'အင်္ဂလိပ် (တောင် ဆူဒန်)',
        'en_SX' => 'အင်္ဂလိပ် (စင့်မာတင်)',
        'en_SZ' => 'အင်္ဂလိပ် (ဆွာဇီလန်)',
        'en_TC' => 'အင်္ဂလိပ် (တခ်စ်နှင့်ကာအီကိုစ်ကျွန်းစု)',
        'en_TK' => 'အင်္ဂလိပ် (တိုကလောင်)',
        'en_TO' => 'အင်္ဂလိပ် (တွန်ဂါ)',
        'en_TT' => 'အင်္ဂလိပ် (ထရီနီဒတ်နှင့် တိုဘက်ဂို)',
        'en_TV' => 'အင်္ဂလိပ် (တူဗားလူ)',
        'en_TZ' => 'အင်္ဂလိပ် (တန်ဇန်းနီးယား)',
        'en_UG' => 'အင်္ဂလိပ် (ယူဂန်းဒါး)',
        'en_UM' => 'အင်္ဂလိပ် (ယူနိုက်တက်စတိတ် ကျွန်းနိုင်ငံများ)',
        'en_US' => 'အင်္ဂလိပ် (အမေရိကန် ပြည်ထောင်စု)',
        'en_VC' => 'အင်္ဂလိပ် (စိန့်ဗင်းဆင့်နှင့် ဂရိနေဒိုင်)',
        'en_VG' => 'အင်္ဂလိပ် (ဗြိတိသျှ ဗာဂျင်း ကျွန်းစု)',
        'en_VI' => 'အင်္ဂလိပ် (ယူအက်စ် ဗာဂျင်း ကျွန်းစု)',
        'en_VU' => 'အင်္ဂလိပ် (ဗနွားတူ)',
        'en_WS' => 'အင်္ဂလိပ် (ဆမိုးအား)',
        'en_ZA' => 'အင်္ဂလိပ် (တောင်အာဖရိက)',
        'en_ZM' => 'အင်္ဂလိပ် (ဇမ်ဘီယာ)',
        'en_ZW' => 'အင်္ဂလိပ် (ဇင်ဘာဘွေ)',
        'eo' => 'အက်စ်ပရန်တို',
        'eo_001' => 'အက်စ်ပရန်တို (ကမ္ဘာ)',
        'es' => 'စပိန်',
        'es_419' => 'စပိန် (လက်တင်အမေရိက)',
        'es_AR' => 'စပိန် (အာဂျင်တီးနား)',
        'es_BO' => 'စပိန် (ဘိုလီးဗီးယား)',
        'es_BR' => 'စပိန် (ဘရာဇီး)',
        'es_BZ' => 'စပိန် (ဘလိဇ်)',
        'es_CL' => 'စပိန် (ချီလီ)',
        'es_CO' => 'စပိန် (ကိုလံဘီယာ)',
        'es_CR' => 'စပိန် (ကို့စ်တာရီကာ)',
        'es_CU' => 'စပိန် (ကျူးဘား)',
        'es_DO' => 'စပိန် (ဒိုမီနီကန်)',
        'es_EC' => 'စပိန် (အီကွေဒေါ)',
        'es_ES' => 'စပိန် (စပိန်)',
        'es_GQ' => 'စပိန် (အီကွေတာ ဂီနီ)',
        'es_GT' => 'စပိန် (ဂွါတီမာလာ)',
        'es_HN' => 'စပိန် (ဟွန်ဒူးရပ်စ်)',
        'es_MX' => 'စပိန် (မက်ကဆီကို)',
        'es_NI' => 'စပိန် (နီကာရာဂွါ)',
        'es_PA' => 'စပိန် (ပနားမား)',
        'es_PE' => 'စပိန် (ပီရူး)',
        'es_PH' => 'စပိန် (ဖိလစ်ပိုင်)',
        'es_PR' => 'စပိန် (ပေါ်တိုရီကို)',
        'es_PY' => 'စပိန် (ပါရာဂွေး)',
        'es_SV' => 'စပိန် (အယ်လ်ဆာဗေးဒိုး)',
        'es_US' => 'စပိန် (အမေရိကန် ပြည်ထောင်စု)',
        'es_UY' => 'စပိန် (ဥရုဂွေး)',
        'es_VE' => 'စပိန် (ဗင်နီဇွဲလား)',
        'et' => 'အက်စ်တိုးနီးယား',
        'et_EE' => 'အက်စ်တိုးနီးယား (အက်စတိုးနီးယား)',
        'eu' => 'ဘာစ်ခ်',
        'eu_ES' => 'ဘာစ်ခ် (စပိန်)',
        'fa' => 'ပါရှန်',
        'fa_AF' => 'ပါရှန် (အာဖဂန်နစ္စတန်)',
        'fa_IR' => 'ပါရှန် (အီရန်)',
        'ff' => 'ဖူလာ',
        'ff_Adlm' => 'ဖူလာ (အက်ဒ်လမ်)',
        'ff_Adlm_BF' => 'ဖူလာ (အက်ဒ်လမ်/ ဘာကီးနား ဖားဆို)',
        'ff_Adlm_CM' => 'ဖူလာ (အက်ဒ်လမ်/ ကင်မရွန်း)',
        'ff_Adlm_GH' => 'ဖူလာ (အက်ဒ်လမ်/ ဂါနာ)',
        'ff_Adlm_GM' => 'ဖူလာ (အက်ဒ်လမ်/ ဂမ်ဘီရာ)',
        'ff_Adlm_GN' => 'ဖူလာ (အက်ဒ်လမ်/ ဂီနီ)',
        'ff_Adlm_GW' => 'ဖူလာ (အက်ဒ်လမ်/ ဂီနီ-ဘီစော)',
        'ff_Adlm_LR' => 'ဖူလာ (အက်ဒ်လမ်/ လိုက်ဘေးရီးယား)',
        'ff_Adlm_MR' => 'ဖူလာ (အက်ဒ်လမ်/ မော်ရီတေးနီးယား)',
        'ff_Adlm_NE' => 'ဖူလာ (အက်ဒ်လမ်/ နိုင်ဂျာ)',
        'ff_Adlm_NG' => 'ဖူလာ (အက်ဒ်လမ်/ နိုင်ဂျီးရီးယား)',
        'ff_Adlm_SL' => 'ဖူလာ (အက်ဒ်လမ်/ ဆီယာရာ လီယွန်း)',
        'ff_Adlm_SN' => 'ဖူလာ (အက်ဒ်လမ်/ ဆီနီဂေါ)',
        'ff_CM' => 'ဖူလာ (ကင်မရွန်း)',
        'ff_GN' => 'ဖူလာ (ဂီနီ)',
        'ff_Latn' => 'ဖူလာ (လက်တင်)',
        'ff_Latn_BF' => 'ဖူလာ (လက်တင်/ ဘာကီးနား ဖားဆို)',
        'ff_Latn_CM' => 'ဖူလာ (လက်တင်/ ကင်မရွန်း)',
        'ff_Latn_GH' => 'ဖူလာ (လက်တင်/ ဂါနာ)',
        'ff_Latn_GM' => 'ဖူလာ (လက်တင်/ ဂမ်ဘီရာ)',
        'ff_Latn_GN' => 'ဖူလာ (လက်တင်/ ဂီနီ)',
        'ff_Latn_GW' => 'ဖူလာ (လက်တင်/ ဂီနီ-ဘီစော)',
        'ff_Latn_LR' => 'ဖူလာ (လက်တင်/ လိုက်ဘေးရီးယား)',
        'ff_Latn_MR' => 'ဖူလာ (လက်တင်/ မော်ရီတေးနီးယား)',
        'ff_Latn_NE' => 'ဖူလာ (လက်တင်/ နိုင်ဂျာ)',
        'ff_Latn_NG' => 'ဖူလာ (လက်တင်/ နိုင်ဂျီးရီးယား)',
        'ff_Latn_SL' => 'ဖူလာ (လက်တင်/ ဆီယာရာ လီယွန်း)',
        'ff_Latn_SN' => 'ဖူလာ (လက်တင်/ ဆီနီဂေါ)',
        'ff_MR' => 'ဖူလာ (မော်ရီတေးနီးယား)',
        'ff_SN' => 'ဖူလာ (ဆီနီဂေါ)',
        'fi' => 'ဖင်လန်',
        'fi_FI' => 'ဖင်လန် (ဖင်လန်)',
        'fo' => 'ဖာရို',
        'fo_DK' => 'ဖာရို (ဒိန်းမတ်)',
        'fo_FO' => 'ဖာရို (ဖာရိုး ကျွန်းစုများ)',
        'fr' => 'ပြင်သစ်',
        'fr_BE' => 'ပြင်သစ် (ဘယ်လ်ဂျီယမ်)',
        'fr_BF' => 'ပြင်သစ် (ဘာကီးနား ဖားဆို)',
        'fr_BI' => 'ပြင်သစ် (ဘူရွန်ဒီ)',
        'fr_BJ' => 'ပြင်သစ် (ဘီနင်)',
        'fr_BL' => 'ပြင်သစ် (စိန့်ဘာသယ်လ်မီ)',
        'fr_CA' => 'ပြင်သစ် (ကနေဒါ)',
        'fr_CD' => 'ပြင်သစ် (ကွန်ဂို)',
        'fr_CF' => 'ပြင်သစ် (ဗဟို အာဖရိက ပြည်ထောင်စု)',
        'fr_CG' => 'ပြင်သစ် (ကွန်ဂို-ဘရာဇာဗီးလ်)',
        'fr_CH' => 'ပြင်သစ် (ဆွစ်ဇာလန်)',
        'fr_CI' => 'ပြင်သစ် (ကို့တ် ဒီဗွာ)',
        'fr_CM' => 'ပြင်သစ် (ကင်မရွန်း)',
        'fr_DJ' => 'ပြင်သစ် (ဂျီဘူတီ)',
        'fr_DZ' => 'ပြင်သစ် (အယ်လ်ဂျီးရီးယား)',
        'fr_FR' => 'ပြင်သစ် (ပြင်သစ်)',
        'fr_GA' => 'ပြင်သစ် (ဂါဘွန်)',
        'fr_GF' => 'ပြင်သစ် (ပြင်သစ် ဂီယာနာ)',
        'fr_GN' => 'ပြင်သစ် (ဂီနီ)',
        'fr_GP' => 'ပြင်သစ် (ဂွါဒီလု)',
        'fr_GQ' => 'ပြင်သစ် (အီကွေတာ ဂီနီ)',
        'fr_HT' => 'ပြင်သစ် (ဟေတီ)',
        'fr_KM' => 'ပြင်သစ် (ကိုမိုရိုစ်)',
        'fr_LU' => 'ပြင်သစ် (လူဇင်ဘတ်)',
        'fr_MA' => 'ပြင်သစ် (မော်ရိုကို)',
        'fr_MC' => 'ပြင်သစ် (မိုနာကို)',
        'fr_MF' => 'ပြင်သစ် (စိန့်မာတင်)',
        'fr_MG' => 'ပြင်သစ် (မဒါဂတ်စကား)',
        'fr_ML' => 'ပြင်သစ် (မာလီ)',
        'fr_MQ' => 'ပြင်သစ် (မာတီနိခ်)',
        'fr_MR' => 'ပြင်သစ် (မော်ရီတေးနီးယား)',
        'fr_MU' => 'ပြင်သစ် (မောရစ်ရှ)',
        'fr_NC' => 'ပြင်သစ် (နယူး ကယ်လီဒိုနီးယား)',
        'fr_NE' => 'ပြင်သစ် (နိုင်ဂျာ)',
        'fr_PF' => 'ပြင်သစ် (ပြင်သစ် ပေါ်လီနီးရှား)',
        'fr_PM' => 'ပြင်သစ် (စိန့်ပီအဲရ်နှင့် မီကွီလွန်)',
        'fr_RE' => 'ပြင်သစ် (ရီယူနီယန်)',
        'fr_RW' => 'ပြင်သစ် (ရဝန်ဒါ)',
        'fr_SC' => 'ပြင်သစ် (ဆေးရှဲ)',
        'fr_SN' => 'ပြင်သစ် (ဆီနီဂေါ)',
        'fr_SY' => 'ပြင်သစ် (ဆီးရီးယား)',
        'fr_TD' => 'ပြင်သစ် (ချဒ်)',
        'fr_TG' => 'ပြင်သစ် (တိုဂို)',
        'fr_TN' => 'ပြင်သစ် (တူနီးရှား)',
        'fr_VU' => 'ပြင်သစ် (ဗနွားတူ)',
        'fr_WF' => 'ပြင်သစ် (ဝေါလစ်နှင့် ဖူကျူးနား)',
        'fr_YT' => 'ပြင်သစ် (မေယော့)',
        'fy' => 'အနောက် ဖရီစီရန်',
        'fy_NL' => 'အနောက် ဖရီစီရန် (နယ်သာလန်)',
        'ga' => 'အိုင်းရစ်ရှ်',
        'ga_GB' => 'အိုင်းရစ်ရှ် (ယူနိုက်တက်ကင်းဒမ်း)',
        'ga_IE' => 'အိုင်းရစ်ရှ် (အိုင်ယာလန်)',
        'gd' => 'စကော့တစ်ရှ် ဂေးလစ်ခ်',
        'gd_GB' => 'စကော့တစ်ရှ် ဂေးလစ်ခ် (ယူနိုက်တက်ကင်းဒမ်း)',
        'gl' => 'ဂါလီစီယာ',
        'gl_ES' => 'ဂါလီစီယာ (စပိန်)',
        'gu' => 'ဂူဂျာရသီ',
        'gu_IN' => 'ဂူဂျာရသီ (အိန္ဒိယ)',
        'gv' => 'မန်းဇ်',
        'gv_IM' => 'မန်းဇ် (မန်ကျွန်း)',
        'ha' => 'ဟာဥစာ',
        'ha_GH' => 'ဟာဥစာ (ဂါနာ)',
        'ha_NE' => 'ဟာဥစာ (နိုင်ဂျာ)',
        'ha_NG' => 'ဟာဥစာ (နိုင်ဂျီးရီးယား)',
        'he' => 'ဟီဘရူး',
        'he_IL' => 'ဟီဘရူး (အစ္စရေး)',
        'hi' => 'ဟိန်ဒူ',
        'hi_IN' => 'ဟိန်ဒူ (အိန္ဒိယ)',
        'hi_Latn' => 'ဟိန်ဒူ (လက်တင်)',
        'hi_Latn_IN' => 'ဟိန်ဒူ (လက်တင်/ အိန္ဒိယ)',
        'hr' => 'ခရိုအေးရှား',
        'hr_BA' => 'ခရိုအေးရှား (ဘော့စနီးယားနှင့် ဟာဇီဂိုဗီနား)',
        'hr_HR' => 'ခရိုအေးရှား (ခရိုအေးရှား)',
        'hu' => 'ဟန်ဂေရီ',
        'hu_HU' => 'ဟန်ဂေရီ (ဟန်ဂေရီ)',
        'hy' => 'အာမေးနီးယား',
        'hy_AM' => 'အာမေးနီးယား (အာမေးနီးယား)',
        'ia' => 'အင်တာလင်ဂွါ',
        'ia_001' => 'အင်တာလင်ဂွါ (ကမ္ဘာ)',
        'id' => 'အင်ဒိုနီးရှား',
        'id_ID' => 'အင်ဒိုနီးရှား (အင်ဒိုနီးရှား)',
        'ig' => 'အစ္ဂဘို',
        'ig_NG' => 'အစ္ဂဘို (နိုင်ဂျီးရီးယား)',
        'ii' => 'စီချွမ် ရီ',
        'ii_CN' => 'စီချွမ် ရီ (တရုတ်)',
        'is' => 'အိုက်စ်လန်',
        'is_IS' => 'အိုက်စ်လန် (အိုက်စလန်)',
        'it' => 'အီတလီ',
        'it_CH' => 'အီတလီ (ဆွစ်ဇာလန်)',
        'it_IT' => 'အီတလီ (အီတလီ)',
        'it_SM' => 'အီတလီ (ဆန်မာရီနို)',
        'it_VA' => 'အီတလီ (ဗာတီကန်စီးတီး)',
        'ja' => 'ဂျပန်',
        'ja_JP' => 'ဂျပန် (ဂျပန်)',
        'jv' => 'ဂျာဗား',
        'jv_ID' => 'ဂျာဗား (အင်ဒိုနီးရှား)',
        'ka' => 'ဂျော်ဂျီယာ',
        'ka_GE' => 'ဂျော်ဂျီယာ (ဂျော်ဂျီယာ)',
        'ki' => 'ကီကူယူ',
        'ki_KE' => 'ကီကူယူ (ကင်ညာ)',
        'kk' => 'ကာဇာချ',
        'kk_KZ' => 'ကာဇာချ (ကာဇက်စတန်)',
        'kl' => 'ကလာအ်လီဆပ်',
        'kl_GL' => 'ကလာအ်လီဆပ် (ဂရင်းလန်း)',
        'km' => 'ခမာ',
        'km_KH' => 'ခမာ (ကမ္ဘောဒီးယား)',
        'kn' => 'ကန်နာဒါ',
        'kn_IN' => 'ကန်နာဒါ (အိန္ဒိယ)',
        'ko' => 'ကိုရီးယား',
        'ko_KP' => 'ကိုရီးယား (မြောက်ကိုရီးယား)',
        'ko_KR' => 'ကိုရီးယား (တောင်ကိုရီးယား)',
        'ks' => 'ကက်ရှ်မီးယား',
        'ks_Arab' => 'ကက်ရှ်မီးယား (အာရေဗျ)',
        'ks_Arab_IN' => 'ကက်ရှ်မီးယား (အာရေဗျ/ အိန္ဒိယ)',
        'ks_Deva' => 'ကက်ရှ်မီးယား (ဒီဗနာဂရီ)',
        'ks_Deva_IN' => 'ကက်ရှ်မီးယား (ဒီဗနာဂရီ/ အိန္ဒိယ)',
        'ks_IN' => 'ကက်ရှ်မီးယား (အိန္ဒိယ)',
        'ku' => 'ကဒ်',
        'ku_TR' => 'ကဒ် (တူရကီ)',
        'kw' => 'ခိုနီရှ်',
        'kw_GB' => 'ခိုနီရှ် (ယူနိုက်တက်ကင်းဒမ်း)',
        'ky' => 'ကာဂျစ်',
        'ky_KG' => 'ကာဂျစ် (ကာဂျစ္စတန်)',
        'lb' => 'လူဇင်ဘတ်',
        'lb_LU' => 'လူဇင်ဘတ် (လူဇင်ဘတ်)',
        'lg' => 'ဂန်ဒါ',
        'lg_UG' => 'ဂန်ဒါ (ယူဂန်းဒါး)',
        'ln' => 'လင်ဂါလာ',
        'ln_AO' => 'လင်ဂါလာ (အန်ဂိုလာ)',
        'ln_CD' => 'လင်ဂါလာ (ကွန်ဂို)',
        'ln_CF' => 'လင်ဂါလာ (ဗဟို အာဖရိက ပြည်ထောင်စု)',
        'ln_CG' => 'လင်ဂါလာ (ကွန်ဂို-ဘရာဇာဗီးလ်)',
        'lo' => 'လာအို',
        'lo_LA' => 'လာအို (လာအို)',
        'lt' => 'လစ်သူဝေးနီးယား',
        'lt_LT' => 'လစ်သူဝေးနီးယား (လစ်သူဝေးနီးယား)',
        'lu' => 'လူဘာ-ကတန်ဂါ',
        'lu_CD' => 'လူဘာ-ကတန်ဂါ (ကွန်ဂို)',
        'lv' => 'လတ်ဗီးယား',
        'lv_LV' => 'လတ်ဗီးယား (လတ်ဗီးယား)',
        'mg' => 'မာလဂက်စီ',
        'mg_MG' => 'မာလဂက်စီ (မဒါဂတ်စကား)',
        'mi' => 'မာအိုရီ',
        'mi_NZ' => 'မာအိုရီ (နယူးဇီလန်)',
        'mk' => 'မက်ဆီဒိုးနီးယား',
        'mk_MK' => 'မက်ဆီဒိုးနီးယား (မြောက် မက်ဆီဒိုးနီးယား)',
        'ml' => 'မလေယာလမ်',
        'ml_IN' => 'မလေယာလမ် (အိန္ဒိယ)',
        'mn' => 'မွန်ဂိုလီးယား',
        'mn_MN' => 'မွန်ဂိုလီးယား (မွန်ဂိုးလီးယား)',
        'mr' => 'မာရသီ',
        'mr_IN' => 'မာရသီ (အိန္ဒိယ)',
        'ms' => 'မလေး',
        'ms_BN' => 'မလေး (ဘရူနိုင်း)',
        'ms_ID' => 'မလေး (အင်ဒိုနီးရှား)',
        'ms_MY' => 'မလေး (မလေးရှား)',
        'ms_SG' => 'မလေး (စင်္ကာပူ)',
        'mt' => 'မော်လ်တာ',
        'mt_MT' => 'မော်လ်တာ (မောလ်တာ)',
        'my' => 'မြန်မာ',
        'my_MM' => 'မြန်မာ (မြန်မာ)',
        'nb' => 'နော်ဝေ ဘွတ်ခ်မော်လ်',
        'nb_NO' => 'နော်ဝေ ဘွတ်ခ်မော်လ် (နော်ဝေ)',
        'nb_SJ' => 'နော်ဝေ ဘွတ်ခ်မော်လ် (စဗိုလ်ဘတ်နှင့်ဂျန်မေရန်)',
        'nd' => 'မြောက် အွန်န်ဒီဘီလီ',
        'nd_ZW' => 'မြောက် အွန်န်ဒီဘီလီ (ဇင်ဘာဘွေ)',
        'ne' => 'နီပေါ',
        'ne_IN' => 'နီပေါ (အိန္ဒိယ)',
        'ne_NP' => 'နီပေါ (နီပေါ)',
        'nl' => 'ဒတ်ခ်ျ',
        'nl_AW' => 'ဒတ်ခ်ျ (အာရူးဗား)',
        'nl_BE' => 'ဒတ်ခ်ျ (ဘယ်လ်ဂျီယမ်)',
        'nl_BQ' => 'ဒတ်ခ်ျ (ကာရစ်ဘီယံ နယ်သာလန်)',
        'nl_CW' => 'ဒတ်ခ်ျ (ကျူရေးကိုးစ်)',
        'nl_NL' => 'ဒတ်ခ်ျ (နယ်သာလန်)',
        'nl_SR' => 'ဒတ်ခ်ျ (ဆူရာနမ်)',
        'nl_SX' => 'ဒတ်ခ်ျ (စင့်မာတင်)',
        'nn' => 'နော်ဝေ နီးနောစ်',
        'nn_NO' => 'နော်ဝေ နီးနောစ် (နော်ဝေ)',
        'no' => 'နော်ဝေ',
        'no_NO' => 'နော်ဝေ (နော်ဝေ)',
        'om' => 'အိုရိုမို',
        'om_ET' => 'အိုရိုမို (အီသီယိုးပီးယား)',
        'om_KE' => 'အိုရိုမို (ကင်ညာ)',
        'or' => 'အိုရီရာ',
        'or_IN' => 'အိုရီရာ (အိန္ဒိယ)',
        'os' => 'အိုဆဲတစ်ခ်',
        'os_GE' => 'အိုဆဲတစ်ခ် (ဂျော်ဂျီယာ)',
        'os_RU' => 'အိုဆဲတစ်ခ် (ရုရှား)',
        'pa' => 'ပန်ချာပီ',
        'pa_Arab' => 'ပန်ချာပီ (အာရေဗျ)',
        'pa_Arab_PK' => 'ပန်ချာပီ (အာရေဗျ/ ပါကစ္စတန်)',
        'pa_Guru' => 'ပန်ချာပီ (ဂူရူ)',
        'pa_Guru_IN' => 'ပန်ချာပီ (ဂူရူ/ အိန္ဒိယ)',
        'pa_IN' => 'ပန်ချာပီ (အိန္ဒိယ)',
        'pa_PK' => 'ပန်ချာပီ (ပါကစ္စတန်)',
        'pl' => 'ပိုလန်',
        'pl_PL' => 'ပိုလန် (ပိုလန်)',
        'ps' => 'ပက်ရှ်တွန်း',
        'ps_AF' => 'ပက်ရှ်တွန်း (အာဖဂန်နစ္စတန်)',
        'ps_PK' => 'ပက်ရှ်တွန်း (ပါကစ္စတန်)',
        'pt' => 'ပေါ်တူဂီ',
        'pt_AO' => 'ပေါ်တူဂီ (အန်ဂိုလာ)',
        'pt_BR' => 'ပေါ်တူဂီ (ဘရာဇီး)',
        'pt_CH' => 'ပေါ်တူဂီ (ဆွစ်ဇာလန်)',
        'pt_CV' => 'ပေါ်တူဂီ (ကိတ်ဗာဒီ)',
        'pt_GQ' => 'ပေါ်တူဂီ (အီကွေတာ ဂီနီ)',
        'pt_GW' => 'ပေါ်တူဂီ (ဂီနီ-ဘီစော)',
        'pt_LU' => 'ပေါ်တူဂီ (လူဇင်ဘတ်)',
        'pt_MO' => 'ပေါ်တူဂီ (မကာအို [တရုတ်ပြည်])',
        'pt_MZ' => 'ပေါ်တူဂီ (မိုဇမ်ဘစ်)',
        'pt_PT' => 'ပေါ်တူဂီ (ပေါ်တူဂီ)',
        'pt_ST' => 'ပေါ်တူဂီ (ဆောင်တူမေးနှင့် ပရင်စီပီ)',
        'pt_TL' => 'ပေါ်တူဂီ (အရှေ့တီမော)',
        'qu' => 'ခီချူဝါအိုဝါ',
        'qu_BO' => 'ခီချူဝါအိုဝါ (ဘိုလီးဗီးယား)',
        'qu_EC' => 'ခီချူဝါအိုဝါ (အီကွေဒေါ)',
        'qu_PE' => 'ခီချူဝါအိုဝါ (ပီရူး)',
        'rm' => 'ရောမ',
        'rm_CH' => 'ရောမ (ဆွစ်ဇာလန်)',
        'rn' => 'ရွန်ဒီ',
        'rn_BI' => 'ရွန်ဒီ (ဘူရွန်ဒီ)',
        'ro' => 'ရိုမေနီယား',
        'ro_MD' => 'ရိုမေနီယား (မောလ်ဒိုဗာ)',
        'ro_RO' => 'ရိုမေနီယား (ရိုမေးနီးယား)',
        'ru' => 'ရုရှ',
        'ru_BY' => 'ရုရှ (ဘီလာရုစ်)',
        'ru_KG' => 'ရုရှ (ကာဂျစ္စတန်)',
        'ru_KZ' => 'ရုရှ (ကာဇက်စတန်)',
        'ru_MD' => 'ရုရှ (မောလ်ဒိုဗာ)',
        'ru_RU' => 'ရုရှ (ရုရှား)',
        'ru_UA' => 'ရုရှ (ယူကရိန်း)',
        'rw' => 'ကင်ရာဝန်ဒါ',
        'rw_RW' => 'ကင်ရာဝန်ဒါ (ရဝန်ဒါ)',
        'sa' => 'သင်္သကရိုက်',
        'sa_IN' => 'သင်္သကရိုက် (အိန္ဒိယ)',
        'sc' => 'ဆာဒီနီးယား',
        'sc_IT' => 'ဆာဒီနီးယား (အီတလီ)',
        'sd' => 'စင်ဒီ',
        'sd_Arab' => 'စင်ဒီ (အာရေဗျ)',
        'sd_Arab_PK' => 'စင်ဒီ (အာရေဗျ/ ပါကစ္စတန်)',
        'sd_Deva' => 'စင်ဒီ (ဒီဗနာဂရီ)',
        'sd_Deva_IN' => 'စင်ဒီ (ဒီဗနာဂရီ/ အိန္ဒိယ)',
        'sd_IN' => 'စင်ဒီ (အိန္ဒိယ)',
        'sd_PK' => 'စင်ဒီ (ပါကစ္စတန်)',
        'se' => 'မြောက် ဆာမိ',
        'se_FI' => 'မြောက် ဆာမိ (ဖင်လန်)',
        'se_NO' => 'မြောက် ဆာမိ (နော်ဝေ)',
        'se_SE' => 'မြောက် ဆာမိ (ဆွီဒင်)',
        'sg' => 'ဆန်ဂို',
        'sg_CF' => 'ဆန်ဂို (ဗဟို အာဖရိက ပြည်ထောင်စု)',
        'si' => 'စင်ဟာလာ',
        'si_LK' => 'စင်ဟာလာ (သီရိလင်္ကာ)',
        'sk' => 'ဆလိုဗက်',
        'sk_SK' => 'ဆလိုဗက် (ဆလိုဗက်ကီးယား)',
        'sl' => 'ဆလိုဗေးနီးယား',
        'sl_SI' => 'ဆလိုဗေးနီးယား (ဆလိုဗေးနီးယား)',
        'sn' => 'ရှိုနာ',
        'sn_ZW' => 'ရှိုနာ (ဇင်ဘာဘွေ)',
        'so' => 'ဆိုမာလီ',
        'so_DJ' => 'ဆိုမာလီ (ဂျီဘူတီ)',
        'so_ET' => 'ဆိုမာလီ (အီသီယိုးပီးယား)',
        'so_KE' => 'ဆိုမာလီ (ကင်ညာ)',
        'so_SO' => 'ဆိုမာလီ (ဆိုမာလီယာ)',
        'sq' => 'အယ်လ်ဘေးနီးယား',
        'sq_AL' => 'အယ်လ်ဘေးနီးယား (အယ်လ်ဘေးနီးယား)',
        'sq_MK' => 'အယ်လ်ဘေးနီးယား (မြောက် မက်ဆီဒိုးနီးယား)',
        'sr' => 'ဆားဘီးယား',
        'sr_BA' => 'ဆားဘီးယား (ဘော့စနီးယားနှင့် ဟာဇီဂိုဗီနား)',
        'sr_Cyrl' => 'ဆားဘီးယား (စစ်ရိလစ်)',
        'sr_Cyrl_BA' => 'ဆားဘီးယား (စစ်ရိလစ်/ ဘော့စနီးယားနှင့် ဟာဇီဂိုဗီနား)',
        'sr_Cyrl_ME' => 'ဆားဘီးယား (စစ်ရိလစ်/ မွန်တီနိဂရိုး)',
        'sr_Cyrl_RS' => 'ဆားဘီးယား (စစ်ရိလစ်/ ဆားဘီးယား)',
        'sr_Latn' => 'ဆားဘီးယား (လက်တင်)',
        'sr_Latn_BA' => 'ဆားဘီးယား (လက်တင်/ ဘော့စနီးယားနှင့် ဟာဇီဂိုဗီနား)',
        'sr_Latn_ME' => 'ဆားဘီးယား (လက်တင်/ မွန်တီနိဂရိုး)',
        'sr_Latn_RS' => 'ဆားဘီးယား (လက်တင်/ ဆားဘီးယား)',
        'sr_ME' => 'ဆားဘီးယား (မွန်တီနိဂရိုး)',
        'sr_RS' => 'ဆားဘီးယား (ဆားဘီးယား)',
        'su' => 'ဆူဒန်',
        'su_ID' => 'ဆူဒန် (အင်ဒိုနီးရှား)',
        'su_Latn' => 'ဆူဒန် (လက်တင်)',
        'su_Latn_ID' => 'ဆူဒန် (လက်တင်/ အင်ဒိုနီးရှား)',
        'sv' => 'ဆွီဒင်',
        'sv_AX' => 'ဆွီဒင် (အာလန်ကျွန်း)',
        'sv_FI' => 'ဆွီဒင် (ဖင်လန်)',
        'sv_SE' => 'ဆွီဒင် (ဆွီဒင်)',
        'sw' => 'ဆွာဟီလီ',
        'sw_CD' => 'ဆွာဟီလီ (ကွန်ဂို)',
        'sw_KE' => 'ဆွာဟီလီ (ကင်ညာ)',
        'sw_TZ' => 'ဆွာဟီလီ (တန်ဇန်းနီးယား)',
        'sw_UG' => 'ဆွာဟီလီ (ယူဂန်းဒါး)',
        'ta' => 'တမီးလ်',
        'ta_IN' => 'တမီးလ် (အိန္ဒိယ)',
        'ta_LK' => 'တမီးလ် (သီရိလင်္ကာ)',
        'ta_MY' => 'တမီးလ် (မလေးရှား)',
        'ta_SG' => 'တမီးလ် (စင်္ကာပူ)',
        'te' => 'တီလီဂူ',
        'te_IN' => 'တီလီဂူ (အိန္ဒိယ)',
        'tg' => 'တာဂျစ်',
        'tg_TJ' => 'တာဂျစ် (တာဂျီကစ္စတန်)',
        'th' => 'ထိုင်း',
        'th_TH' => 'ထိုင်း (ထိုင်း)',
        'ti' => 'တီဂ်ရင်ယာ',
        'ti_ER' => 'တီဂ်ရင်ယာ (အီရီထရီးယား)',
        'ti_ET' => 'တီဂ်ရင်ယာ (အီသီယိုးပီးယား)',
        'tk' => 'တာ့ခ်မင်နစ္စတန်',
        'tk_TM' => 'တာ့ခ်မင်နစ္စတန် (တာ့ခ်မင်နစ္စတန်)',
        'to' => 'တွန်ဂါ',
        'to_TO' => 'တွန်ဂါ (တွန်ဂါ)',
        'tr' => 'တူရကီ',
        'tr_CY' => 'တူရကီ (ဆိုက်ပရပ်စ်)',
        'tr_TR' => 'တူရကီ (တူရကီ)',
        'tt' => 'တာတာ',
        'tt_RU' => 'တာတာ (ရုရှား)',
        'ug' => 'ဝီဂါ',
        'ug_CN' => 'ဝီဂါ (တရုတ်)',
        'uk' => 'ယူကရိန်း',
        'uk_UA' => 'ယူကရိန်း (ယူကရိန်း)',
        'ur' => 'အူရ်ဒူ',
        'ur_IN' => 'အူရ်ဒူ (အိန္ဒိယ)',
        'ur_PK' => 'အူရ်ဒူ (ပါကစ္စတန်)',
        'uz' => 'ဥဇဘတ်',
        'uz_AF' => 'ဥဇဘတ် (အာဖဂန်နစ္စတန်)',
        'uz_Arab' => 'ဥဇဘတ် (အာရေဗျ)',
        'uz_Arab_AF' => 'ဥဇဘတ် (အာရေဗျ/ အာဖဂန်နစ္စတန်)',
        'uz_Cyrl' => 'ဥဇဘတ် (စစ်ရိလစ်)',
        'uz_Cyrl_UZ' => 'ဥဇဘတ် (စစ်ရိလစ်/ ဥဇဘက်ကစ္စတန်)',
        'uz_Latn' => 'ဥဇဘတ် (လက်တင်)',
        'uz_Latn_UZ' => 'ဥဇဘတ် (လက်တင်/ ဥဇဘက်ကစ္စတန်)',
        'uz_UZ' => 'ဥဇဘတ် (ဥဇဘက်ကစ္စတန်)',
        'vi' => 'ဗီယက်နမ်',
        'vi_VN' => 'ဗီယက်နမ် (ဗီယက်နမ်)',
        'wo' => 'ဝူလိုဖ်',
        'wo_SN' => 'ဝူလိုဖ် (ဆီနီဂေါ)',
        'xh' => 'ဇိုစာ',
        'xh_ZA' => 'ဇိုစာ (တောင်အာဖရိက)',
        'yi' => 'ရဟူဒီ',
        'yi_001' => 'ရဟူဒီ (ကမ္ဘာ)',
        'yo' => 'ယိုရူဘာ',
        'yo_BJ' => 'ယိုရူဘာ (ဘီနင်)',
        'yo_NG' => 'ယိုရူဘာ (နိုင်ဂျီးရီးယား)',
        'zh' => 'တရုတ်',
        'zh_CN' => 'တရုတ် (တရုတ်)',
        'zh_HK' => 'တရုတ် (ဟောင်ကောင် [တရုတ်ပြည်])',
        'zh_Hans' => 'တရုတ် (ရိုးရှင်း)',
        'zh_Hans_CN' => 'တရုတ် (ရိုးရှင်း/ တရုတ်)',
        'zh_Hans_HK' => 'တရုတ် (ရိုးရှင်း/ ဟောင်ကောင် [တရုတ်ပြည်])',
        'zh_Hans_MO' => 'တရုတ် (ရိုးရှင်း/ မကာအို [တရုတ်ပြည်])',
        'zh_Hans_SG' => 'တရုတ် (ရိုးရှင်း/ စင်္ကာပူ)',
        'zh_Hant' => 'တရုတ် (ရိုးရာ)',
        'zh_Hant_HK' => 'တရုတ် (ရိုးရာ/ ဟောင်ကောင် [တရုတ်ပြည်])',
        'zh_Hant_MO' => 'တရုတ် (ရိုးရာ/ မကာအို [တရုတ်ပြည်])',
        'zh_Hant_TW' => 'တရုတ် (ရိုးရာ/ ထိုင်ဝမ်)',
        'zh_MO' => 'တရုတ် (မကာအို [တရုတ်ပြည်])',
        'zh_SG' => 'တရုတ် (စင်္ကာပူ)',
        'zh_TW' => 'တရုတ် (ထိုင်ဝမ်)',
        'zu' => 'ဇူးလူး',
        'zu_ZA' => 'ဇူးလူး (တောင်အာဖရိက)',
    ],
];
